<!--
 * @Date: 2024-04-18 21:52:18
 * @LastEditors: Sneed
 * @LastEditTime: 2024-04-21 19:15:52
 * @FilePath: /belleson-frontend/Users/mache/Documents/demo/cps-web/src/views/mdc/components/TimeAlarm.vue
-->
<template>
    <el-row>
        <el-col>
            <el-switch v-model="isShowTable" class="mb-2" active-text="数据表" inactive-text="统计图" />
        </el-col>
        <el-col style="margin-top: 12px;">
            <el-collapse v-model="active" accordion>
                <el-collapse-item title="日 按日查看" name="1">
                    <el-button-group>
                        <el-button size="small" @click="queryDay(item)" :type="valueDay == item.value ? 'primary' : ''"
                            v-for="item in btnListDay" :key="item.value">{{
                                item.label
                            }}</el-button>
                    </el-button-group>
                    <scEcharts v-if="active == 1" style="width:100%" height="300px" :option="dayCharts"></scEcharts>
                </el-collapse-item>
                <el-collapse-item title="周 按周查看" name="2">
                    <el-button-group>
                        <el-button size="small" @click="queryWeek(item)"
                            :type="valueWeek == item.value ? 'primary' : ''" v-for="item in btnListWeek"
                            :key="item.value">{{ item.label
                            }}</el-button>
                    </el-button-group>
                    <scEcharts v-if="active == 2" style="width:100%" height="300px" :option="weekCharts"></scEcharts>
                </el-collapse-item>
                <el-collapse-item title="月 按月查看" name="3">
                    <el-button-group>
                        <el-button size="small" @click="queryMonth(item)"
                            :type="valueMonth == item.value ? 'primary' : ''" v-for="item in btnListMonth"
                            :key="item.value">{{ item.label
                            }}</el-button>
                    </el-button-group>
                    <scEcharts v-if="active == 3" height="300px" :option="monthCharts"></scEcharts>

                </el-collapse-item>
            </el-collapse>
        </el-col>
    </el-row>
</template>

<script>
import scEcharts from '@/components/scEcharts';
import moment from 'moment';
export default {
    props: {
        url: {
            default: '',
            type: String,
        }
    },
    components: {
        scEcharts
    },
    data() {
        return {
            sheetUrl: '/api/blade-mdc/alarm/data-sheet',
            apiObj: '',
            params: {
                enums: "DAY",
                month: 0,
                queryTime: "", //2024-05-21
                shiftIndex: 1,
                week: 0,
                workstationId: "",
                year: 0,
            },
            active: '1',
            valueDay: '',
            valueWeek: '',
            valueMonth: '',
            btnListDay: [],
            btnListWeek: [],
            btnListMonth: [],
            dayCharts: {},
            weekCharts: {},
            monthCharts: {},
        }
    },
    watch: {

    },
    methods: {
        init(params) {
            this.params.workstationId = params.workstationId.toString()
            this.getTime({
                endDate: params.endDate,
                startDate: params.startDate,
            }).then(res => {

            })

        },
        getTime(data) {
            return Promise.all([
                this.$HTTP.post('/api/blade-mdc/efficiency-analysis/interval', {
                    ...data,
                    statisticalMethod: "DAY"
                }).then(res => {
                    if (res.code === 200) {
                        this.btnListDay = res.data.map(item => ({
                            label: item.title,
                            value: item.id,
                            startDate: item.startDate,
                            endDate: item.endDate,
                            week: moment(item.id).week(),
                            month: moment(item.id).month() + 1,
                            year: moment(item.id).year()
                        })).reverse()
                    }
                    this.queryDay(this.btnListDay[0])
                }),
                this.$HTTP.post('/api/blade-mdc/efficiency-analysis/interval', {
                    ...data,
                    statisticalMethod: "WEEK"
                }).then(res => {
                    if (res.code === 200) {
                        this.btnListWeek = res.data.map(item => ({
                            label: item.title,
                            value: item.id,
                            startDate: item.startDate,
                            endDate: item.endDate,
                            week: moment(item.startDate).week(),
                            month: moment(item.startDate).month() + 1,
                            year: moment(item.startDate).year()
                        })).reverse()

                    }
                }),
                this.$HTTP.post('/api/blade-mdc/efficiency-analysis/interval', {
                    ...data,
                    statisticalMethod: "MONTH"
                }).then(res => {
                    if (res.code === 200) {
                        this.btnListMonth = res.data.map(item => ({
                            label: item.title,
                            value: item.id,
                            startDate: item.startDate,
                            endDate: item.endDate,
                            week: moment(item.id + '-1').week(),
                            month: moment(item.id + '-1').month() + 1,
                            year: moment(item.id + '-1').year()
                        })).reverse()

                    }
                })
            ]).then(() => {
                this.queryWeek(this.btnListWeek[0])
                this.queryMonth(this.btnListMonth[0])
            })
        },
        queryDay(row) {
            this.valueDay = row.value
            this.query({
                enums: "DAY",
                queryTime: row.value, //2024-05-21
                week: row.week,
                month: row.month,
                year: row.year,
                shiftIndex: 1,
                workstationId: this.params.workstationId,
            }).then(res => {
                this.dayCharts = res
            })
        },
        queryWeek(row) {
            this.valueWeek = row.value
            console.log(row)
            this.query({
                enums: "WEEK",
                queryTime: this.valueDay,
                week: row.week,
                month: row.month,
                year: row.year,
                workstationId: this.params.workstationId,
            }).then(res => {
                this.weekCharts = res
            })
        },
        queryMonth(row) {
            this.valueMonth = row.value
            this.query({
                enums: "MONTH",
                queryTime: this.valueDay,
                week: row.week,
                month: row.month,
                year: row.year,
                workstationId: this.params.workstationId,
            }).then(res => {
                this.monthCharts = res
            })
        },
        query(data) {
            console.log(data)
            this.queryTableData(data)
            return this.$HTTP.post(this.url, data, {}).then(res => {
                return this.setOptions(res.data.res)
            })
        },
        setOptions(obj) {
            let source = Object.keys(obj)
            let data = Object.values(obj)
            return {
                legend: {
                    type: 'plain',
                },
                title: {
                    text: '',
                    subtext: '',
                },
                grid: {
                    top: '80px'
                },
                tooltip: {
                    trigger: 'axis'
                },
                xAxis: {
                    type: 'category',
                    data: source
                },
                yAxis: {
                    type: 'value'
                },
                dataZoom: [
                    { type: 'slider' }
                ],
                series: [{
                    type: 'bar',
                    data
                }]
            }
        },
        queryTableData() {
            return this.$HTTP.post(this.sheetUrl, data, {}).then(res => {
                this.tableData = res.data.map(item => {
                    return {
                        title: `班次${item.shiftIndex}`,
                        shiftName: item.shiftName,
                        shiftIndex: item.shiftIndex,
                        data: item.alarmDataSheetVOList
                    }
                })
            })
        }
    }
}
</script>

<style lang="scss" scoped></style>